@@ -6,17 +6,17 @@ from archinstall.default_profiles.xorg import XorgProfile
 
 class Xfce4Profile(XorgProfile):
 	def __init__(self) -> None:
-		super().__init__("Xfce4", ProfileType.DesktopEnv)
+		super().__init__('Xfce4', ProfileType.DesktopEnv)
 
 	@property
 	@override
 	def packages(self) -> list[str]:
 		return [
-			"xfce4",
-			"xfce4-goodies",
-			"pavucontrol",
-			"gvfs",
-			"xarchiver",
+			'xfce4',
+			'xfce4-goodies',
+			'pavucontrol',
+			'gvfs',
+			'xarchiver',
 		]
 
 	@property
