@@ -27,5 +27,6 @@ class DockerProfile(Profile):
 	def post_install(self, install_session: 'Installer') -> None:
 		from archinstall.lib.args import arch_config_handler
 
-		for user in arch_config_handler.config.users:
-			install_session.arch_chroot(f'usermod -a -G docker {user.username}')
+		if auth_config := arch_config_handler.config.auth_config:
+			for user in auth_config.users:
+				install_session.arch_chroot(f'usermod -a -G docker {user.username}')
