@@ -13,18 +13,18 @@ from urllib.request import Request, urlopen
 from pydantic.dataclasses import dataclass as p_dataclass
 
 from archinstall.lib.crypt import decrypt
-from archinstall.lib.models.audio_configuration import AudioConfiguration
+from archinstall.lib.models.application import ApplicationConfiguration
+from archinstall.lib.models.authentication import AuthenticationConfiguration
 from archinstall.lib.models.bootloader import Bootloader
-from archinstall.lib.models.device_model import DiskEncryption, DiskLayoutConfiguration
+from archinstall.lib.models.device import DiskEncryption, DiskLayoutConfiguration
 from archinstall.lib.models.locale import LocaleConfiguration
 from archinstall.lib.models.mirrors import MirrorConfiguration
-from archinstall.lib.models.network_configuration import NetworkConfiguration
+from archinstall.lib.models.network import NetworkConfiguration
 from archinstall.lib.models.packages import Repository
-from archinstall.lib.models.profile_model import ProfileConfiguration
-from archinstall.lib.models.users import Password, User
-from archinstall.lib.output import debug, error, warn
+from archinstall.lib.models.profile import ProfileConfiguration
+from archinstall.lib.models.users import Password, User, UserSerialization
+from archinstall.lib.output import debug, error, logger, warn
 from archinstall.lib.plugins import load_plugin
-from archinstall.lib.storage import storage
 from archinstall.lib.translationhandler import Language, tr, translation_handler
 from archinstall.lib.utils.util import get_password
 from archinstall.tui.curses_menu import Tui
@@ -39,10 +39,11 @@ class Arguments:
 	creds_decryption_key: str | None = None
 	silent: bool = False
 	dry_run: bool = False
-	script: str = 'guided'
+	script: str | None = None
 	mountpoint: Path = Path('/mnt')
 	skip_ntp: bool = False
 	skip_wkd: bool = False
+	skip_boot: bool = False
 	debug: bool = False
 	offline: bool = False
 	no_pkg_lookups: bool = False
@@ -55,15 +56,17 @@ class Arguments:
 @dataclass
 class ArchConfig:
 	version: str | None = None
+	script: str | None = None
 	locale_config: LocaleConfiguration | None = None
 	archinstall_language: Language = field(default_factory=lambda: translation_handler.get_language_by_abbr('en'))
 	disk_config: DiskLayoutConfiguration | None = None
 	profile_config: ProfileConfiguration | None = None
 	mirror_config: MirrorConfiguration | None = None
 	network_config: NetworkConfiguration | None = None
-	bootloader: Bootloader = field(default=Bootloader.get_default())
+	bootloader: Bootloader | None = None
 	uki: bool = False
-	audio_config: AudioConfiguration | None = None
+	app_config: ApplicationConfiguration | None = None
+	auth_config: AuthenticationConfiguration | None = None
 	hostname: str = 'archlinux'
 	kernels: list[str] = field(default_factory=lambda: ['linux'])
 	ntp: bool = True
@@ -74,15 +77,15 @@ class ArchConfig:
 	services: list[str] = field(default_factory=list)
 	custom_commands: list[str] = field(default_factory=list)
 
-	# Special fields that should be handle with care due to security implications
-	users: list[User] = field(default_factory=list)
-	root_enc_password: Password | None = None
-
 	def unsafe_json(self) -> dict[str, Any]:
-		config = {
-			'users': [user.json() for user in self.users],
-			'root_enc_password': self.root_enc_password.enc_password if self.root_enc_password else None,
-		}
+		config: dict[str, list[UserSerialization] | str | None] = {}
+
+		if self.auth_config:
+			if self.auth_config.users:
+				config['users'] = [user.json() for user in self.auth_config.users]
+
+			if self.auth_config.root_enc_password:
+				config['root_enc_password'] = self.auth_config.root_enc_password.enc_password
 
 		if self.disk_config:
 			disk_encryption = self.disk_config.disk_encryption
@@ -94,6 +97,7 @@ class ArchConfig:
 	def safe_json(self) -> dict[str, Any]:
 		config: Any = {
 			'version': self.version,
+			'script': self.script,
 			'archinstall-language': self.archinstall_language.json(),
 			'hostname': self.hostname,
 			'kernels': self.kernels,
@@ -104,8 +108,9 @@ class ArchConfig:
 			'timezone': self.timezone,
 			'services': self.services,
 			'custom_commands': self.custom_commands,
-			'bootloader': self.bootloader.json(),
-			'audio_config': self.audio_config.json() if self.audio_config else None,
+			'bootloader': self.bootloader.json() if self.bootloader else None,
+			'app_config': self.app_config.json() if self.app_config else None,
+			'auth_config': self.auth_config.json() if self.auth_config else None,
 		}
 
 		if self.locale_config:
@@ -126,11 +131,14 @@ class ArchConfig:
 		return config
 
 	@classmethod
-	def from_config(cls, args_config: dict[str, Any]) -> 'ArchConfig':
+	def from_config(cls, args_config: dict[str, Any], args: Arguments) -> 'ArchConfig':
 		arch_config = ArchConfig()
 
 		arch_config.locale_config = LocaleConfiguration.parse_arg(args_config)
 
+		if script := args_config.get('script', None):
+			arch_config.script = script
+
 		if archinstall_lang := args_config.get('archinstall-language', None):
 			arch_config.archinstall_language = translation_handler.get_language_by_name(archinstall_lang)
 
@@ -169,21 +177,21 @@ class ArchConfig:
 		if net_config := args_config.get('network_config', None):
 			arch_config.network_config = NetworkConfiguration.parse_arg(net_config)
 
-		# DEPRECATED: backwards copatibility
-		if users := args_config.get('!users', None):
-			arch_config.users = User.parse_arguments(users)
-
-		if users := args_config.get('users', None):
-			arch_config.users = User.parse_arguments(users)
-
 		if bootloader_config := args_config.get('bootloader', None):
-			arch_config.bootloader = Bootloader.from_arg(bootloader_config)
+			arch_config.bootloader = Bootloader.from_arg(bootloader_config, args.skip_boot)
 
-		if args_config.get('uki') and not arch_config.bootloader.has_uki_support():
+		if args_config.get('uki') and (arch_config.bootloader is None or not arch_config.bootloader.has_uki_support()):
 			arch_config.uki = False
 
-		if audio_config := args_config.get('audio_config', None):
-			arch_config.audio_config = AudioConfiguration.parse_arg(audio_config)
+		# deprecated: backwards compatibility
+		audio_config_args = args_config.get('audio_config', None)
+		app_config_args = args_config.get('app_config', None)
+
+		if audio_config_args is not None or app_config_args is not None:
+			arch_config.app_config = ApplicationConfiguration.parse_arg(app_config_args, audio_config_args)
+
+		if auth_config_args := args_config.get('auth_config', None):
+			arch_config.auth_config = AuthenticationConfiguration.parse_arg(auth_config_args)
 
 		if hostname := args_config.get('hostname', ''):
 			arch_config.hostname = hostname
@@ -208,11 +216,30 @@ class ArchConfig:
 			arch_config.services = services
 
 		# DEPRECATED: backwards compatibility
+		root_password = None
 		if root_password := args_config.get('!root-password', None):
-			arch_config.root_enc_password = Password(plaintext=root_password)
+			root_password = Password(plaintext=root_password)
 
 		if enc_password := args_config.get('root_enc_password', None):
-			arch_config.root_enc_password = Password(enc_password=enc_password)
+			root_password = Password(enc_password=enc_password)
+
+		if root_password is not None:
+			if arch_config.auth_config is None:
+				arch_config.auth_config = AuthenticationConfiguration()
+			arch_config.auth_config.root_enc_password = root_password
+
+		# DEPRECATED: backwards copatibility
+		users: list[User] = []
+		if args_users := args_config.get('!users', None):
+			users = User.parse_arguments(args_users)
+
+		if args_users := args_config.get('users', None):
+			users = User.parse_arguments(args_users)
+
+		if users:
+			if arch_config.auth_config is None:
+				arch_config.auth_config = AuthenticationConfiguration()
+			arch_config.auth_config.users = users
 
 		if custom_commands := args_config.get('custom_commands', []):
 			arch_config.custom_commands = custom_commands
@@ -223,12 +250,14 @@ class ArchConfig:
 class ArchConfigHandler:
 	def __init__(self) -> None:
 		self._parser: ArgumentParser = self._define_arguments()
-		self._args: Arguments = self._parse_args()
+		args: Arguments = self._parse_args()
+		self._args = args
 
 		config = self._parse_config()
 
 		try:
-			self._config = ArchConfig.from_config(config)
+			self._config = ArchConfig.from_config(config, args)
+			self._config.version = self._get_version()
 		except ValueError as err:
 			warn(str(err))
 			exit(1)
@@ -241,6 +270,15 @@ class ArchConfigHandler:
 	def args(self) -> Arguments:
 		return self._args
 
+	def get_script(self) -> str:
+		if script := self.args.script:
+			return script
+
+		if script := self.config.script:
+			return script
+
+		return 'guided'
+
 	def print_help(self) -> None:
 		self._parser.print_help()
 
@@ -309,7 +347,6 @@ class ArchConfigHandler:
 		)
 		parser.add_argument(
 			'--script',
-			default='guided',
 			nargs='?',
 			help='Script to run for installation',
 			type=str,
@@ -333,6 +370,12 @@ class ArchConfigHandler:
 			help='Disables checking if archlinux keyring wkd sync is complete.',
 			default=False,
 		)
+		parser.add_argument(
+			'--skip-boot',
+			action='store_true',
+			help='Disables installation of a boot loader (note: only use this when problems arise with the boot loader step).',
+			default=False,
+		)
 		parser.add_argument(
 			'--debug',
 			action='store_true',
@@ -389,7 +432,7 @@ class ArchConfigHandler:
 			args.silent = False
 
 		if args.debug:
-			warn(f'Warning: --debug mode will write certain credentials to {storage["LOG_PATH"]}/{storage["LOG_FILE"]}!')
+			warn(f'Warning: --debug mode will write certain credentials to {logger.path}!')
 
 		if args.plugin:
 			plugin_path = Path(args.plugin)
