@@ -10,7 +10,6 @@ from .general_conf import (
 	add_number_of_parallel_downloads,
 	ask_additional_packages_to_install,
 	ask_for_a_timezone,
-	ask_for_audio_selection,
 	ask_hostname,
 	ask_ntp,
 	select_archinstall_language,
@@ -26,7 +25,6 @@ __all__ = [
 	'ask_additional_packages_to_install',
 	'ask_for_a_timezone',
 	'ask_for_additional_users',
-	'ask_for_audio_selection',
 	'ask_for_bootloader',
 	'ask_for_swap',
 	'ask_for_uki',
