@@ -9,11 +9,11 @@ from .utils import (
 )
 
 __all__ = [
-	"list_keyboard_languages",
-	"list_locales",
-	"list_timezones",
-	"list_x11_keyboard_languages",
-	"set_kb_layout",
-	"verify_keyboard_layout",
-	"verify_x11_keyboard_layout",
+	'list_keyboard_languages',
+	'list_locales',
+	'list_timezones',
+	'list_x11_keyboard_languages',
+	'set_kb_layout',
+	'verify_keyboard_layout',
+	'verify_x11_keyboard_layout',
 ]
