@@ -124,7 +124,7 @@ class CustomMirrorRepositoriesList(ListManager[CustomRepository]):
 				raise ValueError('Unhandled return type')
 
 		header += f'{tr("Signature check")}: {sign_check.value}\n'
-		prompt = f'{header}\n' + 'Select signature option'
+		prompt = f'{header}\n' + tr('Select signature option')
 
 		sign_opt_items = [MenuItem(s.value, value=s.value) for s in SignOption]
 		group = MenuItemGroup(sign_opt_items, sort_items=False)
@@ -258,7 +258,7 @@ class MirrorMenu(AbstractSubMenu[MirrorConfiguration]):
 			),
 		]
 
-	def _prev_regions(self, item: MenuItem) -> str | None:
+	def _prev_regions(self, item: MenuItem) -> str:
 		regions = item.get_value()
 
 		output = ''
@@ -296,8 +296,8 @@ class MirrorMenu(AbstractSubMenu[MirrorConfiguration]):
 		return output.strip()
 
 	@override
-	def run(self) -> MirrorConfiguration:
-		super().run()
+	def run(self, additional_title: str | None = None) -> MirrorConfiguration:
+		super().run(additional_title=additional_title)
 		return self._mirror_config
 
 
@@ -438,7 +438,7 @@ class MirrorListHandler:
 		region_list = mappings[region]
 		return sorted(region_list, key=lambda mirror: (mirror.score, mirror.speed))
 
-	def _parse_remote_mirror_list(self, mirrorlist: str) -> dict[str, list[MirrorStatusEntryV3]] | None:
+	def _parse_remote_mirror_list(self, mirrorlist: str) -> dict[str, list[MirrorStatusEntryV3]]:
 		mirror_status = MirrorStatusListV3.model_validate_json(mirrorlist)
 
 		sorting_placeholder: dict[str, list[MirrorStatusEntryV3]] = {}
@@ -472,7 +472,7 @@ class MirrorListHandler:
 
 		return sorted_by_regions
 
-	def _parse_locale_mirrors(self, mirrorlist: str) -> dict[str, list[MirrorStatusEntryV3]] | None:
+	def _parse_locale_mirrors(self, mirrorlist: str) -> dict[str, list[MirrorStatusEntryV3]]:
 		lines = mirrorlist.splitlines()
 
 		# remove empty lines
