@@ -8,10 +8,11 @@ from ..output import warn
 
 
 class Bootloader(Enum):
-	Systemd = "Systemd-boot"
-	Grub = "Grub"
-	Efistub = "Efistub"
-	Limine = "Limine"
+	NO_BOOTLOADER = 'No bootloader'
+	Systemd = 'Systemd-boot'
+	Grub = 'Grub'
+	Efistub = 'Efistub'
+	Limine = 'Limine'
 
 	def has_uki_support(self) -> bool:
 		match self:
@@ -23,24 +24,27 @@ class Bootloader(Enum):
 	def json(self) -> str:
 		return self.value
 
-	@staticmethod
-	def values() -> list[str]:
-		return [e.value for e in Bootloader]
-
 	@classmethod
 	def get_default(cls) -> Bootloader:
-		if SysInfo.has_uefi():
+		from ..args import arch_config_handler
+
+		if arch_config_handler.args.skip_boot:
+			return Bootloader.NO_BOOTLOADER
+		elif SysInfo.has_uefi():
 			return Bootloader.Systemd
 		else:
 			return Bootloader.Grub
 
 	@classmethod
-	def from_arg(cls, bootloader: str) -> Bootloader:
+	def from_arg(cls, bootloader: str, skip_boot: bool) -> Bootloader:
 		# to support old configuration files
 		bootloader = bootloader.capitalize()
 
-		if bootloader not in cls.values():
-			values = ", ".join(cls.values())
+		bootloader_options = [e.value for e in Bootloader if e != Bootloader.NO_BOOTLOADER or skip_boot is True]
+
+		if bootloader not in bootloader_options:
+			values = ', '.join(bootloader_options)
 			warn(f'Invalid bootloader value "{bootloader}". Allowed values: {values}')
 			sys.exit(1)
+
 		return Bootloader(bootloader)
