@@ -127,7 +127,7 @@ class MenuItemGroup:
 		preset: Enum | None = None,
 	) -> 'MenuItemGroup':
 		items = [MenuItem(elem.value, value=elem) for elem in enum_cls]
-		group = MenuItemGroup(items, sort_items=False)
+		group = MenuItemGroup(items, sort_items=sort_items)
 
 		if preset is not None:
 			group.set_selected_by_value(preset)
@@ -196,6 +196,7 @@ class MenuItemGroup:
 
 		max_width = self._max_items_text_width
 		display_text = item.get_display_value()
+
 		default_text = self._default_suffix(item)
 
 		text = unicode_ljust(str(item.text), max_width, ' ')
@@ -273,6 +274,9 @@ class MenuItemGroup:
 		self.focus_item = enabled[index]
 
 	def focus_first(self) -> None:
+		if len(self.items) == 0:
+			return
+
 		first_item: MenuItem | None = self.items[0]
 
 		if first_item and not self._is_selectable(first_item):
@@ -282,6 +286,9 @@ class MenuItemGroup:
 			self.focus_item = first_item
 
 	def focus_last(self) -> None:
+		if len(self.items) == 0:
+			return
+
 		last_item: MenuItem | None = self.items[-1]
 
 		if last_item and not self._is_selectable(last_item):
